==> pegasus-merchandise-api-2.2.16-sources.jar: com/thebeastshop/pegasus/merchandise/cond/InvHomeSkuCond.java <==
/**
 * Copyright (C), 上海布鲁爱电子商务有限公司
 */
package com.thebeastshop.pegasus.merchandise.cond;

import com.thebeastshop.pegasus.util.cond.BaseQueryCond;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.List;

/**
 * @author Royan
 * @version $Id: ScmWarehouseSkuCond.java, v 0.1 2015-08-07 下午5:58
 */
public class InvHomeSkuCond extends BaseQueryCond implements Serializable {

    private Integer brandId;

    private String placeOfOrigin;

    private String skuCode;

    private String skuName;

    private List<Integer> categoryIds;					// 品类

    private String prodCode;

    private String warehouseCode;

    private BigDecimal salePriceBegin;

    private BigDecimal salePriceEnd;

    private List<String> skuList;                      //通过prod查询sku后，和现有sku组合起来作为搜索条件

    public Integer getBrandId() {
        return brandId;
    }

    public void setBrandId(Integer brandId) {
        this.brandId = brandId;
    }

    public String getPlaceOfOrigin() {
        return placeOfOrigin;
    }

    public void setPlaceOfOrigin(String placeOfOrigin) {
        this.placeOfOrigin = placeOfOrigin;
    }

    public String getSkuCode() {
        return skuCode;
    }

    public void setSkuCode(String skuCode) {
        this.skuCode = skuCode;
    }

    public String getSkuName() {
        return skuName;
    }

    public void setSkuName(String skuName) {
        this.skuName = skuName;
    }

    public List<Integer> getCategoryIds() {
        return categoryIds;
    }

    public void setCategoryIds(List<Integer> categoryIds) {
        this.categoryIds = categoryIds;
    }

    public String getProdCode() {
        return prodCode;
    }

    public void setProdCode(String prodCode) {
        this.prodCode = prodCode;
    }

    public String getWarehouseCode() {
        return warehouseCode;
    }

    public void setWarehouseCode(String warehouseCode) {
        this.warehouseCode = warehouseCode;
    }

    public BigDecimal getSalePriceBegin() {
        return salePriceBegin;
    }

    public void setSalePriceBegin(BigDecimal salePriceBegin) {
        this.salePriceBegin = salePriceBegin;
    }

    public BigDecimal getSalePriceEnd() {
        return salePriceEnd;
    }

    public void setSalePriceEnd(BigDecimal salePriceEnd) {
        this.salePriceEnd = salePriceEnd;
    }

    public List<String> getSkuList() {
        return skuList;
    }

    public void setSkuList(List<String> skuList) {
        this.skuList = skuList;
    }
}

==> pegasus-merchandise-api-3.3.8-sources.jar: com/thebeastshop/pegasus/merchandise/cond/InvHomeSkuCond.java <==
/**
 * Copyright (C), 上海布鲁爱电子商务有限公司
 */
package com.thebeastshop.pegasus.merchandise.cond;
import com.thebeastshop.common.BaseQueryCond;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.List;

/**
 * @author Royan
 * @version $Id: ScmWarehouseSkuCond.java, v 0.1 2015-08-07 下午5:58
 */
public class InvHomeSkuCond extends BaseQueryCond implements Serializable {

    private Integer brandId;

    private String placeOfOrigin;

    private String skuCode;

    private String skuName;

    private List<Integer> categoryIds;					// 品类

    private String prodCode;

    private String warehouseCode;

    private BigDecimal salePriceBegin;

    private BigDecimal salePriceEnd;

    private List<String> skuList;                      //通过prod查询sku后，和现有sku组合起来作为搜索条件

    public Integer getBrandId() {
        return brandId;
    }

    public void setBrandId(Integer brandId) {
        this.brandId = brandId;
    }

    public String getPlaceOfOrigin() {
        return placeOfOrigin;
    }

    public void setPlaceOfOrigin(String placeOfOrigin) {
        this.placeOfOrigin = placeOfOrigin;
    }

    public String getSkuCode() {
        return skuCode;
    }

    public void setSkuCode(String skuCode) {
        this.skuCode = skuCode;
    }

    public String getSkuName() {
        return skuName;
    }

    public void setSkuName(String skuName) {
        this.skuName = skuName;
    }

    public List<Integer> getCategoryIds() {
        return categoryIds;
    }

    public void setCategoryIds(List<Integer> categoryIds) {
        this.categoryIds = categoryIds;
    }

    public String getProdCode() {
        return prodCode;
    }

    public void setProdCode(String prodCode) {
        this.prodCode = prodCode;
    }

    public String getWarehouseCode() {
        return warehouseCode;
    }

    public void setWarehouseCode(String warehouseCode) {
        this.warehouseCode = warehouseCode;
    }

    public BigDecimal getSalePriceBegin() {
        return salePriceBegin;
    }

    public void setSalePriceBegin(BigDecimal salePriceBegin) {
        this.salePriceBegin = salePriceBegin;
    }

    public BigDecimal getSalePriceEnd() {
        return salePriceEnd;
    }

    public void setSalePriceEnd(BigDecimal salePriceEnd) {
        this.salePriceEnd = salePriceEnd;
    }

    public List<String> getSkuList() {
        return skuList;
    }

    public void setSkuList(List<String> skuList) {
        this.skuList = skuList;
    }
}
